<?php
/**
 * @wordpress-plugin
 * Plugin Name:       Divi 404 Page Builder
 * Plugin URI:        https://divicake.com/products/divi-404-page-builder/
 * Description:       Instantly create 404 pages using Divi.
 * Version:           1.0.0
 * Author:            CODECRATER
 * Author URI:        https://divicake.com/author/CODECRATER/
 * Text Domain:       cc-divi-404-page
*/

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
	
	define('_CCD4P_PLUGIN_VERSION_', '1.0.0');
	
	
	/**
	 * Perform requirement checks
	 * @since  1.0.0
	*/
	add_action( 'admin_init', 'plugin_has_required_theme' );
	function plugin_has_required_theme() {
		if ( is_admin() && current_user_can( 'activate_plugins' ) && !cc_is_divi_active() ) {
			add_action( 'admin_notices', 'cc_plugin_notice' );
			deactivate_plugins( plugin_basename( __FILE__ ) );
			if ( isset( $_GET['activate'] ) ) {
				unset( $_GET['activate'] );
			}
		}
	}
	
	
	/**
	 * Initialize the plugin
	 * @since  1.0.0
	*/
	function cc_plugin_notice() {
		echo '<div class="error"><p>Sorry, but Divi 404 Page Builder requires the Divi Page Builder to be installed and active to function.</p></div>';
	}
	
	
	/**
	 * Checks if Divi is enabled
	 * @return bool isactive
	 * @since  1.0.0
	*/
	function cc_is_divi_active() {
		if ( function_exists( 'et_setup_theme' ) ) {
			return true;
		} else {
			return false;
		}
	}
	
	
	/**
	 * Initialize the plugin
	 * @since  1.0.0
	*/
	function cc_divi_404_page_init() {
		add_filter( 'plugin_action_links_' . plugin_basename(__FILE__), 'cc_divi_404_page_add_settings_link', 10, 2 );
		require_once( 'includes/cc_divi_404_page-core.php' );
		require_once( 'includes/cc_divi_404_page-settings.php' );
	}
	cc_divi_404_page_init();
	

	/**
	 * Enqueue Admin Styles
	 * @since  1.0.0
	*/
	add_action('admin_footer', 'cc_divi_404_page_admin_scripts');
	function cc_divi_404_page_admin_scripts() {
		echo '<style type="text/css">';
		echo '#cc_divi_404_page_settingpage_wrapper tr{background:#d7d7d7;padding:0 20px;display:block;border-radius:10px;margin:20px 0}';
		echo '#cc_divi_404_page_settingpage_wrapper form{margin-top:50px}';
		echo '#cc_divi_404_page_settingpage_wrapper h1{margin-top:1em}';
		echo '#cc_divi_404_page_settingpage_wrapper{padding-right:20px}';
		echo 'body.settings_page_cc_divi_404_page .notice,body.settings_page_cc_divi_404_page div.error,body.settings_page_cc_divi_404_page div.updated {margin:20px 0 0 0}';
		echo '</style>';
	}
	
	
	/**
	 * Adds settings link to the plugin on WP-Admin / Plugins page
	 * @param array $links Default plugin links
	 * @return array Plugin links
	 * @since  1.0.0
	 */
	function cc_divi_404_page_add_settings_link( $links ){
		$settings = sprintf( '<a href="%1$s">%2$s</a>',
			esc_url( admin_url( 'options-general.php?page=cc_divi_404_page' ) ),
			esc_html__( 'Settings', 'et_automatic_updates' )
		);
		array_push( $links, $settings );
		return $links;
	}


	/**
	 * Plugin Updater
	 * @since  1.0.0
	*/
	require_once( 'includes/plugin_update_check.php' );
	$MyUpdateChecker = new PluginUpdateChecker_2_0 (
	    'https://kernl.us/api/v1/updates/5aa2f9e75a5c3e051e253446/',
	    __FILE__,
	    'cc-divi-404-page',
	    1
	);