<?php
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Init settings page.
 * @since 1.0.0
 */
add_action( 'admin_menu', 'cc_divi_404_page_add_admin_menu' );
add_action( 'admin_init', 'cc_divi_404_page_settings_init' );


/**
 * Add menu.
 * @since 1.0.0
 */
function cc_divi_404_page_add_admin_menu() {
	add_submenu_page( 'options-general.php', 'Divi 404 Page Builder', 'Divi 404 Page Builder', 'manage_options', 'cc_divi_404_page', 'cc_divi_404_page_options_page' );
}


/**
 * Init settings page.
 * @since 1.0.0
 */
function cc_divi_404_page_settings_init() { 
	register_setting( 'pluginPage', 'cc_divi_404_page_settings' );
	add_settings_section(
		'cc_divi_404_page_pluginPage_section', 
		__( 'Select a Divi layout to use as your 404 page.', 'cc-divi-404-page' ),
		'cc_divi_404_page_settings_section_callback', 
		'pluginPage'
	);
	add_settings_field( 
		'cc_divi_404_page_librarylayout_choices_select_field', 
		__( 'Select a Divi Library Layout', 'cc-divi-404-page' ), 
		'cc_divi_404_page_librarylayout_choices_select_field_render', 
		'pluginPage', 
		'cc_divi_404_page_pluginPage_section' 
	);
}


/**
 * Get Divi Library Layout list.
 * @since 1.0.0
 */
function cc_divi_404_page_get_librarylayout_choices( $options ) {
	// List all Divi Library layouts
	$librarylayoutReturnValue = '';
	$librarylayoutBlacklist = array(
		'About Me',
		'About Us',
		'Blog Masonry',
		'Blog Standard',
		'Case Study',
		'Coming Soon',
		'Contact Us',
		'Creative Agency',
		'Divi Builder Demo'
	); // Layouts included with Divi.
	$orig_post = $post;
	global $post;
	$args = array(
		'post_type' => 'et_pb_layout',
		'tax_query' => array(
			'taxonomy' => 'layout_type',
			'field'    => 'slug',
			'terms'    => 'layout'
		),
		'post_status' => 'publish',
		'posts_per_page' => -1,
		'order' => 'ASC',
		'orderby' => 'title',
	);
	$my_query = new WP_Query($args);
	if( $my_query->have_posts() ) {
		while ($my_query->have_posts()) : $my_query->the_post();

		// manually filter out blacklisted layouts?
		$layout_title = get_the_title();
		$layout_id = get_the_id();
		
		// filter out any with 'layout_type' not equal to 'layout'
		if ( has_term( 'layout', 'layout_type', $layout_id ) ) {
		    continue;
		}
		$librarylayoutReturnValue .= '<option value="' . $layout_id . '"';
		$librarylayoutReturnValue .= selected( $options['cc_divi_404_page_librarylayout_choices_select_field'], $layout_id, false );
		$librarylayoutReturnValue .= '>' . $layout_title . '</option>';
		
		endwhile;
	}
	$post = $orig_post;
	wp_reset_query();

	return $librarylayoutReturnValue;
}
		

/**
 * Render layout choices field.
 * @since 1.0.0
 */
function cc_divi_404_page_librarylayout_choices_select_field_render() {
	$options = get_option( 'cc_divi_404_page_settings' );
?>
	<select id="cc_divi_404_page_librarylayout_choices" name='cc_divi_404_page_settings[cc_divi_404_page_librarylayout_choices_select_field]'>
		<option disabled value="none">Select an Option</option>
		<?php echo cc_divi_404_page_get_librarylayout_choices( $options ); ?>
	</select>
	<a href="/wp-admin/post.php?post=<?php echo $options['cc_divi_404_page_librarylayout_choices_select_field']; ?>&action=edit" class="button" id="edit_layout_btn">Edit This Layout</a>
<?php
}


/**
 * Callback function. Currently unused.
 * @since 1.0.0
 */
function cc_divi_404_page_settings_section_callback() { 
	//echo __( '', 'cc-divi-404-page' ); // Disabled for now.
}


/**
 * Render Options Page.
 * @since 1.0.0
 */
function cc_divi_404_page_options_page() {?>
	<div id="cc_divi_404_page_settingpage_wrapper">
		
		<img src="<?php echo plugin_dir_url( __FILE__ ); ?>/Divi-404-Page-Builder-Plugin-Title.png" alt="Divi 404 Page Builder" title="Divi 404 Page Builder" style="margin:10px 0;border-radius:5px;overflow:hidden" />
		
		<div>
			<a href="/wp-admin/post-new.php?post_type=et_pb_layout" class="button">New Layout</a>
			<a href="/Divi404PreviewABC123/" class="button" target="_blank">View 404 Page</a>
		</div>
		
		<form action='options.php' method='post'>
			<?php
			settings_fields( 'pluginPage' );
			do_settings_sections( 'pluginPage' );
			?>
			
			<?php
			submit_button();
			?>
			
			<p>&copy; <?php echo date('Y'); ?> CODECRATER. Version <?php echo _CCD4P_PLUGIN_VERSION_; ?> Thank you for your support! Need help? <a href="https://divicake.com/products/divi-404-page-builder/" target="_blank">Read the documentation here</a>.</p>
			
			<p>Do you enjoy this plugin? Please consider <a href="https://divicake.com/products/divi-404-page-builder/" target="_blank">leaving a review on Divi Cake here</a>.</p>
			
		</form>
		<script type="text/javascript">
			jQuery('#cc_divi_404_page_librarylayout_choices').on('change', function() {
				jQuery('#edit_layout_btn').attr('href', '/wp-admin/post.php?post=' + this.value + '&action=edit');
			});
		</script>
	</div>
	<?php
}
?>